==> vtwidget_1_0.tar.gz: vtwidget_1_0/bterm/help_msg.h <==

/*******************************************************************************
       help_msg.h
       This header file is included by help_msg.c

*******************************************************************************/

#ifndef	_HELP_MSG_INCLUDED
#define	_HELP_MSG_INCLUDED


#include <stdio.h>
#include <Xm/Xm.h>
#include <Xm/MwmUtil.h>
#include <Xm/DialogS.h>
#include <Xm/MenuShell.h>
#include "UxXt.h"

#include <Xm/MessageB.h>

/*******************************************************************************
       The definition of the context structure:
       If you create multiple copies of your interface, the context
       structure ensures that your callbacks use the variables for the
       correct copy.

       For each swidget in the interface, each argument to the Interface
       function, and each variable in the Interface Specific section of the
       Declarations Editor, there is an entry in the context structure.
       and a #define.  The #define makes the variable name refer to the
       corresponding entry in the context structure.
*******************************************************************************/

typedef	struct
{
	Widget	Uxhelp_msg;
	swidget	UxUxParent;
} _UxChelp_msg;

#ifdef CONTEXT_MACRO_ACCESS
static _UxChelp_msg            *UxHelp_msgContext;
#define help_msg                UxHelp_msgContext->Uxhelp_msg
#define UxParent                UxHelp_msgContext->UxUxParent

#endif /* CONTEXT_MACRO_ACCESS */


/*******************************************************************************
       Declarations of global functions.
*******************************************************************************/

Widget	create_help_msg();

#endif	/* _HELP_MSG_INCLUDED */

==> vtwidget-1.3.tar.gz: vtwidget-1.3/bterm/help_msg.h <==

/*******************************************************************************
       help_msg.h
       This header file is included by help_msg.c

*******************************************************************************/

#ifndef	_HELP_MSG_INCLUDED
#define	_HELP_MSG_INCLUDED

#include <stdio.h>

#ifdef MOTIF
#include <Xm/Xm.h>
#include <Xm/MwmUtil.h>
#include <Xm/DialogS.h>
#include <Xm/MenuShell.h>
#endif /* MOTIF */

#include "UxXt.h"

#ifndef XKLOADDS
#define XKLOADDS
#endif /* XKLOADDS */

/*******************************************************************************
       The definition of the context structure:
       If you create multiple copies of your interface, the context
       structure ensures that your callbacks use the variables for the
       correct copy.

       For each swidget in the interface, each argument to the Interface
       function, and each variable in the Interface Specific section of the
       Declarations Editor, there is an entry in the context structure
       and a #define.  The #define makes the variable name refer to the
       corresponding entry in the context structure.
*******************************************************************************/

typedef	struct
{
	Widget	Uxhelp_msg;
	swidget	UxUxParent;
} _UxChelp_msg;

#ifdef CONTEXT_MACRO_ACCESS
static _UxChelp_msg            *UxHelp_msgContext;
#define help_msg                UxHelp_msgContext->Uxhelp_msg
#define UxParent                UxHelp_msgContext->UxUxParent

#endif /* CONTEXT_MACRO_ACCESS */


/*******************************************************************************
       Declarations of global functions.
*******************************************************************************/

Widget	create_help_msg( swidget _UxUxParent );

#endif	/* _HELP_MSG_INCLUDED */
